@@ -115,6 +115,7 @@ public class ResourceIcon implements Icon {
         CLEAR = makeIcon( "newdoc1.png" ),
         HIDE_WINDOWS = makeIcon( "hide1.png" ),
         SCROLLER = makeIcon( "scroll2.png" ),
+        STILTS = makeIcon( "stilts.png" ),
 
         /* Windows. */
         CONTROL = makeIcon( "controlw.png" ),
@@ -235,6 +236,7 @@ public class ResourceIcon implements Icon {
         CDSXMATCH = makeIcon( "xm3.png" ),
         HISTO_SAVE = makeIcon( "histo-save.png" ),
         HISTO_IMPORT = makeIcon( "histo-import.png" ),
+        WARNING = makeIcon( "warning_triangle.png" ),
 
         /* Plot2 icons. */
         UP_DOWN = makeIcon( "updown8.png" ),
@@ -705,7 +707,10 @@ public class ResourceIcon implements Icon {
         putMap( nameMap, "ADD_FORM_SIZE", toAddIcon( TTRI.FORM_SIZE ) );
         putMap( nameMap, "ADD_FORM_VECTOR", toAddIcon( TTRI.FORM_VECTOR ) );
         putMap( nameMap, "ADD_FORM_ERROR", toAddIcon( TTRI.FORM_ERROR ) );
-        putMap( nameMap, "ADD_FORM_ELLIPSE", toAddIcon( TTRI.FORM_ELLIPSE ) );
+        putMap( nameMap, "ADD_FORM_XYELLIPSE",
+                         toAddIcon( TTRI.FORM_XYELLIPSE ) );
+        putMap( nameMap, "ADD_FORM_SKYELLIPSE",
+                         toAddIcon( TTRI.FORM_SKYELLIPSE ) );
         putMap( nameMap, "ADD_PLOT_LINE", toAddIcon( TTRI.PLOT_LINE ) );
         putMap( nameMap, "ADD_FORM_LINEARFIT",
                          toAddIcon( TTRI.FORM_LINEARFIT ) );
