@@ -42,6 +42,7 @@ import uk.ac.starlink.table.RowListStarTable;
 import uk.ac.starlink.table.ShapeIterator;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.StarTableOutput;
+import uk.ac.starlink.table.TableBuilder;
 import uk.ac.starlink.table.ValueInfo;
 import uk.ac.starlink.table.gui.StarTableColumn;
 import uk.ac.starlink.ttools.jel.RandomJELRowReader;
@@ -79,6 +80,7 @@ public class TopcatModel {
     private final ToggleButtonModel rowSendModel_;
     private final Collection listeners_;
     private final Map columnSelectorMap_;
+    private final TableBuilder tableBuilder_;
     private SubsetConsumerDialog subsetConsumerDialog_;
     private final int id_;
     private final ControlWindow controlWindow_;
@@ -111,6 +113,12 @@ public class TopcatModel {
                            ControlWindow controlWindow ) {
         controlWindow_ = controlWindow;
 
+        /* Pull out the information about the input table format that
+         * should have been stashed in the table's parametr list
+         * by the TopcatTableFactory.  Remove the relevant parameter from
+         * the list so that the rest of the application doesn't see it. */
+        tableBuilder_ = TopcatPreparation.removeFormatParameter( startab );
+
         /* Ensure that we have random access. */
         if ( ! startab.isRandom() && startab.getRowCount() != 0 ) {
             throw new IllegalArgumentException( "Can't use non-random table" );
@@ -282,6 +290,16 @@ public class TopcatModel {
         return id_;
     }
 
+    /**
+     * Returns the table builder object that originally loaded
+     * this model's table.
+     *
+     * @return   table origin input handler if known, or null
+     */
+    public TableBuilder getTableFormat() {
+        return tableBuilder_;
+    }
+
     public String toString() {
         return id_ + ": " + getLabel();
     }
@@ -660,21 +678,6 @@ public class TopcatModel {
         };
     }
 
-    /**
-     * Returns a unique ID string for the given table column, which
-     * should be one of the columns in this object's dataModel
-     * (though not necessarily its columnModel).  The id will consist
-     * of a '$' sign followed by an integer.
-     *
-     * @param   cinfo column metadata
-     * @return  ID string
-     */
-    public String getColumnID( ColumnInfo cinfo ) {
-        return cinfo.getAuxDatum( TopcatUtils.COLID_INFO )
-                    .getValue()
-                    .toString();
-    }
-
     /**
      * Appends a new column to the existing table at a given column index.
      * This method appends a column to the dataModel, fixes the
