@@ -185,17 +185,19 @@ public abstract class FormLayerControl
      */
     protected abstract boolean isControlActive( FormControl fc );
 
-    public PlotLayer[] getPlotLayers() {
+    public TopcatLayer[] getLayers() {
         RowSubset[] subsets = subStack_.getSelectedSubsets();
         GuiCoordContent[] posContents = posCoordPanel_.getContents();
         if ( tcModel_ == null || posContents == null || subsets == null ) {
-            return new PlotLayer[ 0 ];
+            return new TopcatLayer[ 0 ];
         }
         DataGeom geom = posCoordPanel_.getDataGeom();
+        ConfigMap coordConfig = posCoordPanel_.getConfig();
         FormControl[] fcs = getActiveFormControls();
-        List<PlotLayer> layerList = new ArrayList<PlotLayer>();
+        List<TopcatLayer> layerList = new ArrayList<TopcatLayer>();
         for ( int is = 0; is < subsets.length; is++ ) {
             RowSubset subset = subsets[ is ];
+            String leglabel = getLegendLabel( subset );
             for ( int ifc = 0; ifc < fcs.length; ifc++ ) {
                 FormControl fc = fcs[ ifc ];
                 GuiCoordContent[] extraContents = fc.getExtraCoordContents();
@@ -204,14 +206,21 @@ public abstract class FormLayerControl
                         PlotUtil.arrayConcat( posContents, extraContents );
                     DataSpec dspec =
                         new GuiDataSpec( tcModel_, subset, contents );
-                    PlotLayer layer = fc.createLayer( geom, dspec, subset );
-                    if ( layer != null ) {
+                    PlotLayer plotLayer = fc.createLayer( geom, dspec, subset );
+                    if ( plotLayer != null ) {
+                        ConfigMap config = new ConfigMap();
+                        config.putAll( coordConfig );
+                        config.putAll( fc.getExtraConfig() );
+                        config.putAll( fc.getStylePanel().getConfig( subset ) );
+                        TopcatLayer layer =
+                            new TopcatLayer( plotLayer, config, leglabel,
+                                             tcModel_, contents, subset );
                         layerList.add( layer );
                     }
                 }
             }
         }
-        return layerList.toArray( new PlotLayer[ 0 ] );
+        return layerList.toArray( new TopcatLayer[ 0 ] );
     }
 
     public LegendEntry[] getLegendEntries() {
@@ -219,18 +228,12 @@ public abstract class FormLayerControl
             return new LegendEntry[ 0 ];
         }
         Map<RowSubset,List<Style>> rsetStyles =
-            getStylesBySubset( getPlotLayers() );
+            getStylesBySubset( getLayers() );
         List<LegendEntry> entries = new ArrayList<LegendEntry>();
         for ( RowSubset rset : rsetStyles.keySet() ) {
             Style[] styles = rsetStyles.get( rset ).toArray( new Style[ 0 ] );
-            ConfigMap config =
-                subsetManager_.getConfigger( rset ).getConfig();
-            boolean show = config.get( StyleKeys.SHOW_LABEL );
-            if ( show ) {
-                String label = config.get( StyleKeys.LABEL );
-                if ( label == null || label.trim().length() == 0 ) {
-                    label = tcModel_.getID() + ": " + rset.getName();
-                }
+            String label = getLegendLabel( rset );
+            if ( label != null ) {
                 LegendEntry entry = new LegendEntry( label, styles );
                 assert entry.equals( new LegendEntry( label, styles ) );
                 entries.add( entry );
@@ -239,6 +242,31 @@ public abstract class FormLayerControl
         return entries.toArray( new LegendEntry[ 0 ] );
     }
 
+    /**
+     * Returns the label to use in the legend for a given row subset
+     * controlled by this control.  Null means the item should not appear
+     * in the legend.
+     *
+     * @param  rset  row subset
+     * @return  legend label, or null if absent from legend
+     */
+    private String getLegendLabel( RowSubset rset ) {
+        if ( rset == null ) {
+            return null;
+        }
+        ConfigMap config = subsetManager_.getConfigger( rset ).getConfig();
+        boolean show = config.get( StyleKeys.SHOW_LABEL );
+        if ( show ) {
+            String label = config.get( StyleKeys.LABEL );
+            return label == null || label.trim().length() == 0
+                 ? tcModel_.getID() + ": " + rset.getName()
+                 : label;
+        }
+        else {
+            return null;
+        }
+    }
+
     public Specifier<ZoneId> getZoneSpecifier() {
         return zsel_;
     }
@@ -322,15 +350,15 @@ public abstract class FormLayerControl
      * Returns all those style objects associated with a given RowSubset
      * for a given list of plot layers.
      *
-     * @param    layers  plot layers
+     * @param    tcLayers   layers
      * @return   ordered RowSubset->Styles map
      */
     private static Map<RowSubset,List<Style>>
-                   getStylesBySubset( PlotLayer[] layers ) {
+                   getStylesBySubset( TopcatLayer[] tcLayers ) {
         Map<RowSubset,List<Style>> map =
             new LinkedHashMap<RowSubset,List<Style>>();
-        for ( int il = 0; il < layers.length; il++ ) {
-            PlotLayer layer = layers[ il ];
+        for ( TopcatLayer tcLayer : tcLayers ) {
+            PlotLayer layer = tcLayer.getPlotLayer();
             DataSpec dspec = layer.getDataSpec();
             if ( dspec != null ) {
                 Object mask = dspec.getMaskId();
