@@ -8,6 +8,7 @@ import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.Shape;
+import java.awt.Window;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
@@ -59,6 +60,7 @@ import uk.ac.starlink.topcat.TopcatEvent;
 import uk.ac.starlink.topcat.TopcatListener;
 import uk.ac.starlink.topcat.TopcatModel;
 import uk.ac.starlink.topcat.TopcatUtils;
+import uk.ac.starlink.topcat.WindowToggle;
 import uk.ac.starlink.ttools.plot.Range;
 import uk.ac.starlink.ttools.plot2.AuxScale;
 import uk.ac.starlink.ttools.plot2.DataGeom;
@@ -68,6 +70,7 @@ import uk.ac.starlink.ttools.plot2.Ganger;
 import uk.ac.starlink.ttools.plot2.Gesture;
 import uk.ac.starlink.ttools.plot2.IndicatedRow;
 import uk.ac.starlink.ttools.plot2.LegendEntry;
+import uk.ac.starlink.ttools.plot2.LegendIcon;
 import uk.ac.starlink.ttools.plot2.Navigator;
 import uk.ac.starlink.ttools.plot2.Padding;
 import uk.ac.starlink.ttools.plot2.PlotLayer;
@@ -121,6 +124,7 @@ public class StackPlotWindow<P,A> extends AuxWindow {
     private final ControlManager controlManager_;
     private final MultiAxisController<P,A> multiAxisController_;
     private final MultiController<ShaderControl> multiShaderControl_;
+    private final MultiConfigger[] zoneConfiggers_;
     private final ToggleButtonModel showProgressModel_;
     private final LegendControl legendControl_;
     private final FrameControl frameControl_;
@@ -240,13 +244,37 @@ public class StackPlotWindow<P,A> extends AuxWindow {
         /* Set up a plot panel with the objects it needs to gather plot
          * requirements from the GUI.  This does the actual plotting. */
         plotPanel_ =
-            new PlotPanel<P,A>( storeFact, surfFact_, gangerFact, zonesFact,
-                                posFact, plotType.getPaperTypeSelector(),
+            new PlotPanel<P,A>( plotType_, storeFact, surfFact_,
+                                gangerFact, zonesFact, posFact,
+                                plotType.getPaperTypeSelector(),
                                 compositor, sketchModel_,
                                 placeProgressBar().getModel(),
                                 showProgressModel_, axisLockModel_,
                                 auxLockModel_ );
 
+        zoneConfiggers_ = new MultiConfigger[] {
+            configger, 
+            multiAxisController_.getConfigger(),
+            multiShaderControl_.getConfigger(),
+        };
+
+        /* Prepare options to display the text of a STILTS command
+         * corresponding to the current plot. */
+        final boolean isMultiZone =
+            plotTypeGui_.getGangerFactory().isMultiZone();
+        ToggleButtonModel stiltsWindowToggle =
+                 new WindowToggle( "STILTS Command Window", ResourceIcon.STILTS,
+                                   "Display this information "
+                                 + "in a separate window" ) {
+            protected Window createWindow() {
+                return new StiltsDialog( StackPlotWindow.this, plotPanel_,
+                                         isMultiZone );
+            }
+        };
+        Control stiltsControl =
+            new StiltsControl( plotPanel_, isMultiZone, stiltsWindowToggle );
+        stackPanel_.addFixedControl( stiltsControl );
+
         /* Ensure that the plot panel is messaged when a GUI action occurs
          * that might change the plot appearance.  Each of these controls
          * is forwarding actions from all of its constituent controls. */
@@ -316,7 +344,7 @@ public class StackPlotWindow<P,A> extends AuxWindow {
             public void stateChanged( ChangeEvent evt ) {
                 plotChanged();
             }
-        } );
+        }, false );
 
         /* Prepare the action that allows the user to select the currently
          * visible points. */
@@ -536,6 +564,7 @@ public class StackPlotWindow<P,A> extends AuxWindow {
         exportMenu_ = new JMenu( "Export" );
         exportMenu_.setMnemonic( KeyEvent.VK_E );
         exportMenu_.add( exportAction );
+        exportMenu_.add( stiltsWindowToggle.createMenuItem() );
         layerDataImportMenu_ = new JMenu( "Layer Data Import" );
         layerDataImportMenu_.setIcon( ResourceIcon.IMPORT );
         layerDataImportMenu_.setToolTipText( "Options to import table into "
@@ -728,8 +757,9 @@ public class StackPlotWindow<P,A> extends AuxWindow {
         List<PlotLayer> layerList = new ArrayList<PlotLayer>();
         LayerControl[] controls = stackModel_.getLayerControls( activeOnly );
         for ( int ic = 0; ic < controls.length; ic++ ) {
-            PlotLayer[] layers = controls[ ic ].getPlotLayers();
-            layerList.addAll( Arrays.asList( layers ) );
+            for ( TopcatLayer tcLayer : controls[ ic ].getLayers() ) {
+                layerList.add( tcLayer.getPlotLayer() );
+            }
         }
         return layerList.toArray( new PlotLayer[ 0 ] );
     }
@@ -786,14 +816,15 @@ public class StackPlotWindow<P,A> extends AuxWindow {
               getLayerControlsByZone().entrySet() ) {
             final ZoneId zid = entry.getKey();
             LayerControl[] controls = entry.getValue();
-            List<PlotLayer> layerList = new ArrayList<PlotLayer>();
+            List<TopcatLayer> layerList = new ArrayList<TopcatLayer>();
             List<LegendEntry> legList = new ArrayList<LegendEntry>();
             for ( LayerControl control : controls ) {
-                layerList.addAll( Arrays.asList( control.getPlotLayers() ) );
+                layerList.addAll( Arrays.asList( control.getLayers() ) );
                 legList.addAll( Arrays.asList( control.getLegendEntries() ) );
             }
-            final PlotLayer[] layers = layerList.toArray( new PlotLayer[ 0 ] );
-            final Icon legend =
+            final TopcatLayer[] layers =
+                layerList.toArray( new TopcatLayer[ 0 ] );
+            final LegendIcon legend =
                 legendControl_
                .createLegendIcon( legList.toArray( new LegendEntry[ 0 ] ),
                                   zid );
@@ -808,6 +839,10 @@ public class StackPlotWindow<P,A> extends AuxWindow {
             final Range shadeFixRange = shaderControl.getFixRange();
             final Subrange shadeSubrange = shaderControl.getSubrange();
             final boolean isShadeLog = shaderControl.isLog();
+            final ConfigMap config = new ConfigMap();
+            for ( MultiConfigger zc : zoneConfiggers_ ) {
+                config.putAll( zc.getZoneConfig( zid ) );
+            }
             zdefs.add( new ZoneDef<P,A>() {
                 public ZoneId getZoneId() {
                     return zid;
@@ -815,10 +850,10 @@ public class StackPlotWindow<P,A> extends AuxWindow {
                 public AxisController<P,A> getAxisController() {
                     return axisController;
                 }
-                public PlotLayer[] getLayers() {
+                public TopcatLayer[] getLayers() {
                     return layers;
                 }
-                public Icon getLegend() {
+                public LegendIcon getLegend() {
                     return legend;
                 }
                 public float[] getLegendPosition() {
@@ -839,6 +874,9 @@ public class StackPlotWindow<P,A> extends AuxWindow {
                 public boolean isShadeLog() {
                     return isShadeLog;
                 }
+                public ConfigMap getConfig() {
+                    return config;
+                }
             } );
         }
         return (ZoneDef<P,A>[]) zdefs.toArray( new ZoneDef[ 0 ] );
@@ -1322,7 +1360,7 @@ public class StackPlotWindow<P,A> extends AuxWindow {
                         return null;
                     }
                 }
-                PlotUtil.logTime( logger_, "Count", start );
+                PlotUtil.logTimeFromStart( logger_, "Count", start );
                 return TopcatUtils.formatLong( count ) + " / "
                      + TopcatUtils.formatLong( total );
             }
@@ -1407,7 +1445,7 @@ public class StackPlotWindow<P,A> extends AuxWindow {
                         return null;
                     }
                 }
-                PlotUtil.logTime( logger_, "Subset", start );
+                PlotUtil.logTimeFromStart( logger_, "Subset", start );
                 return maskMap;
             }
         } );
@@ -1628,7 +1666,7 @@ public class StackPlotWindow<P,A> extends AuxWindow {
      * @param  layers  plot layers
      * @return   true iff any uses an aux colour shader
      */
-    private static boolean hasShadedLayers( PlotLayer[] layers ) {
+    public static boolean hasShadedLayers( PlotLayer[] layers ) {
         for ( int il = 0; il < layers.length; il++ ) {
             if ( layers[ il ].getAuxRangers().keySet()
                                              .contains( AuxScale.COLOR ) ) {
