@@ -1,6 +1,6 @@
 package uk.ac.starlink.topcat;
 
-import java.awt.HeadlessException;
+import gnu.jel.CompilationException;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -28,7 +28,7 @@ import uk.ac.starlink.votable.VOTableWriter;
 
 public class CodecTest extends TableCase {
 
-    private final TopcatCodec codec_;
+    private final TopcatCodec[] allCodecs_;
     private final ControlWindow controlWindow_;
     private final StarTableWriter tWriter_;
     private final TableBuilder tReader_;
@@ -37,23 +37,20 @@ public class CodecTest extends TableCase {
         Logger.getLogger( "uk.ac.starlink.table" ).setLevel( Level.WARNING );
         Logger.getLogger( "org.astrogrid.samp" ).setLevel( Level.WARNING );
         Logger.getLogger( "uk.ac.starlink.topcat" ).setLevel( Level.WARNING );
-        codec_ = TopcatCodec.getInstance();
-        ControlWindow cwin;
-        try {
-            cwin = ControlWindow.getInstance();
-        }
-        catch ( HeadlessException e ) {
-            cwin = null;
-        }
-        controlWindow_ = cwin;
+        controlWindow_ = null;
         tWriter_ = new VOTableWriter();
         tReader_ = new VOTableBuilder();
+        allCodecs_ = TopcatUtils.SESSION_DECODERS.clone();
     }
 
-    public void testCodec() throws IOException {
-        if ( controlWindow_ == null ) {
-            System.err.println( "headless: no codec test" );
+    public void testCodecs() throws IOException, CompilationException {
+        for ( TopcatCodec codec : allCodecs_ ) {
+            exerciseCodec( codec );
         }
+    }
+
+    private void exerciseCodec( TopcatCodec codec )
+            throws IOException, CompilationException {
         StarTable[] demoTables = Driver.getDemoTables();
         int nt = demoTables.length;
         TopcatModel[] tcModels = new TopcatModel[ nt ];
@@ -62,15 +59,29 @@ public class CodecTest extends TableCase {
                 new TopcatModel( demoTables[ i ], "demo" + ( i + 1 ),
                                  controlWindow_ );
             assertEqualTopcatModels( tcModels[ i ],
-                                     roundTrip( tcModels[ i ] ) );
+                                     roundTrip( codec, tcModels[ i ] ) );
         }
 
         TopcatModel tcModel = tcModels[ 1 ];
+        long nrow = tcModel.getDataModel().getRowCount();
         BitSet mask = new BitSet();
         mask.set( 0, 10 );
         RowSubset tenSet = new BitsRowSubset( "Ten", mask );
+        RowSubset notTenSet = new InverseRowSubset( tenSet );
+        RowSubset evenSet =
+            new SyntheticRowSubset( "Even", "$0 % 2 == 0",
+                                    tcModel.createJELRowReader() );
         tcModel.addSubset( RowSubset.NONE );
         tcModel.addSubset( tenSet );
+        tcModel.addSubset( notTenSet );
+        tcModel.addSubset( evenSet );
+        assertEquals( 0, countSubset( RowSubset.NONE, nrow ) );
+        assertEquals( 10, countSubset( tenSet, nrow ) );
+        assertEquals( nrow - 10, countSubset( notTenSet, nrow ) );
+        assertEquals( ( nrow + 1 ) / 2, countSubset( evenSet, nrow ) );
+
+        RowSubset removed = (RowSubset) tcModel.getSubsets().remove( 3 );
+        assertEquals( notTenSet, removed );
         tcModel.applySubset( tenSet );
         tcModel.sortBy( new SortOrder( tcModel.getColumnModel()
                                               .getColumn( 2 ) ), true );
@@ -82,7 +93,7 @@ public class CodecTest extends TableCase {
         colModel.removeColumn( colModel.getColumn( 0 ) );
         colModel.removeColumn( colModel
                               .getColumn( colModel .getColumnCount() - 1 ) );
-        TopcatModel tcModel1 = roundTrip( tcModel );
+        TopcatModel tcModel1 = roundTrip( codec, tcModel );
         assertEqualTopcatModels( tcModel, tcModel1 );
     }
 
@@ -117,8 +128,9 @@ public class CodecTest extends TableCase {
         }
     }
 
-    private TopcatModel roundTrip( TopcatModel tcModel ) throws IOException {
-        StarTable oTable = codec_.encode( tcModel );
+    private TopcatModel roundTrip( TopcatCodec codec, TopcatModel tcModel )
+                                   throws IOException {
+        StarTable oTable = codec.encode( tcModel );
         ByteArrayOutputStream bout = new ByteArrayOutputStream();
         tWriter_.writeStarTable( oTable, bout );
         bout.close();
@@ -126,6 +138,19 @@ public class CodecTest extends TableCase {
         StarTable iTable = tReader_
            .makeStarTable( new ByteArrayDataSource( loc, bout.toByteArray() ),
                            true, StoragePolicy.PREFER_MEMORY );
-        return codec_.decode( iTable, loc, controlWindow_ );
+        for ( TopcatCodec aCodec : allCodecs_ ) {
+            assertEquals( aCodec.isEncoded( iTable ), aCodec.equals( codec ) );
+        }
+        return codec.decode( iTable, loc, controlWindow_ );
+    }
+
+    private int countSubset( RowSubset rset, long nrow ) {
+        int n = 0;
+        for ( long i = 0; i < nrow; i++ ) {
+            if ( rset.isIncluded( i ) ) {
+                n++;
+            }
+        }
+        return n;
     }
 }
